@@ -35,7 +35,7 @@ DOCKER_DEFAULT_VOLUMES = (
     "results",
 )
 
-DEFAULT_BASE_IMAGE = f"python:{version_info.major}.{version_info.minor}-buster"
+DEFAULT_BASE_IMAGE = f"python:{version_info.major}.{version_info.minor}-slim"
 DIVE_IMAGE = "wagoodman/dive:latest"
 
 
@@ -198,7 +198,7 @@ def docker_build(
 def _mount_info() -> Dict[str, Union[str, Tuple]]:
     res = dict(
         host_root=str(Path.cwd()),
-        container_root="/home/kedro",
+        container_root="/home/kedro_docker",
         mount_volumes=DOCKER_DEFAULT_VOLUMES,
     )
     return res
